@@ -40,8 +40,10 @@ class DtypeTransformer(BaseTransformer):
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
         Transform the dataframe by converting the columns to the specified dtypes.
+
         Args:
             X (pandas.DataFrame): dataframe to transform.
+
         Returns:
             pandas.DataFrame: Transformed dataframe.
         """
@@ -64,25 +66,27 @@ class AggregateTransformer(BaseTransformer):
     from sk_transformers.generic_transformer import AggregateTransformer
 
     X = pd.DataFrame(
-    {
-        "foo": ["mr", "mr", "ms", "ms", "ms", "mr", "mr", "mr", "mr", "ms"],
-        "bar": [46, 32, 78, 48, 93, 68, 53, 38, 76, 56],
-    }
+        {
+            "foo": ["mr", "mr", "ms", "ms", "ms", "mr", "mr", "mr", "mr", "ms"],
+            "bar": [46, 32, 78, 48, 93, 68, 53, 38, 76, 56],
+        }
+    )
 
     transformer = AggregateTransformer([("foo", "bar", ["mean"])])
-    transformer.fit_transform(X).to_numpy()
+    transformer.fit_transform(X)
     ```
     ```
-    array([["mr", 46, 52.17...],
-            ["mr", 32, 52.17...],
-            ["ms", 78, 68.75],
-            ["ms", 48, 68.75],
-            ["ms", 93, 68.75],
-            ["mr", 68, 52.17...],
-            ["mr", 53, 52.17...],
-            ["mr", 38, 52.17...],
-            ["mr", 76, 52.17...],
-            ["ms", 56, 68.75]], dtype=object)
+      foo  bar  MEAN(foo__bar)
+    0  mr   46       52.166668
+    1  mr   32       52.166668
+    2  ms   78       68.750000
+    3  ms   48       68.750000
+    4  ms   93       68.750000
+    5  mr   68       52.166668
+    6  mr   53       52.166668
+    7  mr   38       52.166668
+    8  mr   76       52.166668
+    9  ms   56       68.750000
     ```
 
     Args:
@@ -145,17 +149,19 @@ class FunctionsTransformer(BaseTransformer):
 
     Example:
     ```python
+    import numpy as np
     import pandas as pd
     from sk_transformers.generic_transformer import FunctionsTransformer
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
     transformer = FunctionsTransformer([("foo", np.log1p, None), ("bar", np.sqrt, None)])
-    transformer.fit_transform(X).to_numpy()
+    transformer.fit_transform(X)
     ```
     ```
-    array([[0.6931..., 2.        ],
-            [1.0986..., 2.2360...],
-            [1.3862..., 2.4494...]])
+            foo       bar
+    0  0.693147  2.000000
+    1  1.098612  2.236068
+    2  1.386294  2.449490
     ```
 
     Args:
@@ -172,7 +178,7 @@ class FunctionsTransformer(BaseTransformer):
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
-        Applies the functions to the columns. And returns the dataframe with the modified columns.
+        Applies the functions to the columns, and returns the dataframe with the modified columns.
 
         Args:
             X (pandas.DataFrame): DataFrame containing the columns to apply the functions on.
@@ -194,7 +200,7 @@ class FunctionsTransformer(BaseTransformer):
 class MapTransformer(BaseTransformer):
     """
     This transformer iterates over all columns in the `features` list and applies the given callback to the column.
-    For this it uses the `pandas.Series.map` method.
+    For this it uses the [`pandas.Series.map`](https://pandas.pydata.org/docs/reference/api/pandas.Series.map.html) method.
 
     Example:
     ```python
@@ -203,16 +209,17 @@ class MapTransformer(BaseTransformer):
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
     transformer = MapTransformer([("foo", lambda x: x + 1)])
-    transformer.fit_transform(X).to_numpy()
+    transformer.fit_transform(X)
     ```
     ```
-    array([[2, 4],
-            [3, 5],
-            [4, 6]])
+       foo  bar
+    0    2    4
+    1    3    5
+    2    4    6
     ```
 
     Args:
-        features (List[str, Callable]): List of tuples containing the name of the
+        features (List[Tuple[str, Callable]]): List of tuples containing the name of the
             column to apply the callback on and the callback itself.
     """
 
@@ -226,6 +233,7 @@ class MapTransformer(BaseTransformer):
 
         Args:
             X (pandas.DataFrame): Dataframe containing the the columns to apply the callback on.
+
         Returns:
             pandas.DataFrame: The dataframe containing
                 the new column together with the non-transformed original columns.
@@ -243,6 +251,22 @@ class ColumnDropperTransformer(BaseTransformer):
     """
     Drops columns from a dataframe using Pandas `drop` method.
 
+    Example:
+    ```python
+    import pandas as pd
+    from sk_transformers.generic_transformer import ColumnDropperTransformer
+
+    X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
+    transformer = ColumnDropperTransformer(["foo"])
+    transformer.fit_transform(X)
+    ```
+    ```
+       bar
+    0    4
+    1    5
+    2    6
+    ```
+
     Args:
         columns (Union[str, List[str]]): Columns to drop. Either a single column name or a list of column names.
     """
@@ -267,15 +291,32 @@ class ColumnDropperTransformer(BaseTransformer):
 
 class NaNTransformer(BaseTransformer):
     """
-    Replace NaN values with a specified value. Internally Pandas `fillna` method is used.
+    Replace NaN values with a specified value. Internally Pandas [`fillna`](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.fillna.html) method is used.
+
+    Example:
+    ```python
+    from sk_transformers.generic_transformer import NaNTransformer
+    import pandas as pd
+    import numpy as np
+
+    X = pd.DataFrame({"foo": [1, np.NaN, 3], "bar": ["a", np.NaN, "c"]})
+    transformer = NaNTransformer([("foo", -999), ("bar", "-999")])
+    transformer.fit_transform(X)
+    ```
+    ```
+          foo   bar
+    0     1.0     a
+    1  -999.0  -999
+    2     3.0     c
+    ```
 
     Args:
-        values (Dict[str, Any]): Dictionary with column names as keys and values to replace NaN with as values.
+        features (List[Tuple[str, Any]]): List of tuples where the first element is the column name, and the second is the value to replace NaN with.
     """
 
-    def __init__(self, values: Dict[str, Any]) -> None:
+    def __init__(self, features: List[Tuple[str, Any]]) -> None:
         super().__init__()
-        self.values = values
+        self.features = features
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
@@ -287,8 +328,13 @@ class NaNTransformer(BaseTransformer):
         Returns:
             pandas.DataFrame: Transformed dataframe.
         """
-        X = check_ready_to_transform(self, X, force_all_finite="allow-nan")
-        return X.fillna(self.values)
+        X = check_ready_to_transform(
+            self,
+            X,
+            [feature[0] for feature in self.features],
+            force_all_finite="allow-nan",
+        )
+        return X.fillna(dict(self.features))
 
 
 class ValueIndicatorTransformer(BaseTransformer):
@@ -307,16 +353,15 @@ class ValueIndicatorTransformer(BaseTransformer):
     import pandas as pd
 
     X = pd.DataFrame({"foo": [1, -999, 3], "bar": ["a", "-999", "c"]})
-    transformer = NaNIndicatorTransformer([("foo", -999), ("bar", "-999")])
+    transformer = ValueIndicatorTransformer([("foo", -999), ("bar", "-999")])
     transformer.fit_transform(X).to_dict()
     ```
     ```
-    {
-        'foo': {0: 1, 1: -999, 2: 3},
-        'bar': {0: 'a', 1: '-999', 2: 'c'},
-        'foo_found_indicator': {0: False, 1: True, 2: False},
-        'bar_found_indicator': {0: False, 1: True, 2: False}
-    }
+       foo   bar  foo_found_indicator  bar_found_indicator
+    0    1     a                False                False
+    1 -999  -999                 True                 True
+    2    3     c                False                False
+    ```
 
     Args:
         features (List[Tuple[str, Any]]): A list of tuples where the first value in represents the column
@@ -361,6 +406,23 @@ class QueryTransformer(BaseTransformer):
     also removes the corresponding `y` value.
     Read more about queries [here](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.query.html).
 
+    Example:
+    ```python
+    import pandas as pd
+    from sk_transformers.generic_transformer import QueryTransformer
+
+    X = pd.DataFrame({"foo": [1, 8, 3, 6, 5, 4, 7, 2]})
+    transformer = QueryTransformer(["foo > 4"])
+    transformer.fit_transform(X)
+    ```
+    ```
+       foo
+    1    8
+    3    6
+    4    5
+    6    7
+    ```
+
     Args:
         queries (List[str]): List of query string to evaluate to the dataframe.
     """
@@ -399,26 +461,28 @@ class ValueReplacerTransformer(BaseTransformer):
     import pandas as pd
     from sk_transformers.generic_transformer import ValueReplacerTransformer
 
-    X = pd.DataFrame({"foo": ["0000-01-01", "2022/01/08", "bar", "1982-12-7", "28-09-2022"]})
-    transformer = (
-        ValueReplacerTransformer(
-            [
-                (
-                    ["foo"],
-                    r"^(?!(19|20)\d\d[-\/.](0[1-9]|1[012]|[1-9])[-\/.](0[1-9]|[12][0-9]|3[01]|[1-9])$).*",
-                    "1900-01-01",
-                )
-            ]
-        ),
+    X = pd.DataFrame(
+        {"foo": ["0000-01-01", "2022/01/08", "bar", "1982-12-7", "28-09-2022"]}
     )
-    transformer.fit_transform(X).to_numpy()
+    transformer = ValueReplacerTransformer(
+        [
+            (
+                ["foo"],
+                r"^(?!(19|20)\d\d[-\/.](0[1-9]|1[012]|[1-9])[-\/.](0[1-9]|[12][0-9]|3[01]|[1-9])$).*",
+                "1900-01-01",
+            )
+        ]
+    )
+
+    transformer.fit_transform(X)
     ```
     ```
-    array([['1900-01-01'],
-            ['2022/01/08'],
-            ['1900-01-01'],
-            ['1982-12-7'],
-            ['1900-01-01']], dtype=object)
+              foo
+    0  1900-01-01
+    1  2022/01/08
+    2  1900-01-01
+    3   1982-12-7
+    4  1900-01-01
     ```
 
 
@@ -433,6 +497,8 @@ class ValueReplacerTransformer(BaseTransformer):
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
+        Replaces a value or regular expression with another value.
+
         Args:
             X (pd.DataFrame): Dataframe containing the columns where values should be replaced.
 
@@ -469,3 +535,70 @@ class ValueReplacerTransformer(BaseTransformer):
         except re.error:
             is_valid = False
         return is_valid
+
+
+class LeftJoinTransformer(BaseTransformer):
+    """
+    Performs a database-style left-join using `pd.merge`. This transformer is suitable for
+    replacing values in a column of a dataframe by looking-up another `pd.DataFrame`
+    or `pd.Series`. Note that, the join is based on the index of the right dataframe.
+
+    Example:
+    ```python
+    import pandas as pd
+    from sk_transformers.generic_transformer import LeftJoinTransformer
+
+    X = pd.DataFrame({"foo": ["A", "B", "C", "A", "C"]})
+    lookup_df = pd.Series([1, 2, 3], index=["A", "B", "C"], name="values")
+    transformer = LeftJoinTransformer([("foo", lookup_df)])
+    transformer.fit_transform(X)
+    ```
+    ```
+      foo  foo_values
+    0   A           1
+    1   B           2
+    2   C           3
+    3   A           1
+    4   C           3
+    ```
+
+    Args:
+        features (List[Tuple[str, Union[pd.Series, pd.DataFrame]]]): A list of tuples
+            where the first element is the name of the column
+            and the second element is the look-up dataframe or series.
+    """
+
+    def __init__(
+        self, features: List[Tuple[str, Union[pd.Series, pd.DataFrame]]]
+    ) -> None:
+        super().__init__()
+        self.features = features
+
+    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
+        """
+        Perform a left-join on the given columns of a dataframe with another cooresponding dataframe.
+
+        Args:
+            X (pd.DataFrame): Dataframe containing the columns to be joined on.
+
+        Returns:
+            pd.DataFrame: Dataframe joined on the given columns.
+        """
+
+        X = check_ready_to_transform(self, X, [feature[0] for feature in self.features])
+
+        for (column, lookup_df) in self.features:
+            lookup_df = LeftJoinTransformer.__prefix_df_column_names(lookup_df, column)
+            X = pd.merge(X, lookup_df, how="left", left_on=column, right_index=True)
+
+        return X
+
+    @staticmethod
+    def __prefix_df_column_names(
+        df: Union[pd.Series, pd.DataFrame], prefix: str
+    ) -> Union[pd.Series, pd.DataFrame]:
+        if isinstance(df, pd.Series):
+            df.name = prefix + "_" + (df.name if df.name else "lookup")
+        elif isinstance(df, pd.DataFrame):
+            df.columns = [prefix + "_" + column for column in df.columns]
+        return df
